Struct Oeccr
#[repr(transparent)]pub struct Oeccr(pub u32);Expand description
This register contains the offset compensation value.
Tuple Fields
0: u32Implementations
impl Oeccr
impl Oeccr
pub const fn offset(&self) -> u32
pub const fn offset(&self) -> u32
Offset error compensation Set and cleared by software. If the application attempts to write a new offset value while the previous one is not yet applied, this new offset value is ignored. Reading back the OFFSET[25:0] field will inform the application on the current offset value. OFFSET[25:0] represents the value to be subtracted to the signal before going to the SCALE.
pub const fn set_offset(&mut self, val: u32)
pub const fn set_offset(&mut self, val: u32)
Offset error compensation Set and cleared by software. If the application attempts to write a new offset value while the previous one is not yet applied, this new offset value is ignored. Reading back the OFFSET[25:0] field will inform the application on the current offset value. OFFSET[25:0] represents the value to be subtracted to the signal before going to the SCALE.