Struct Oldthhr
#[repr(transparent)]pub struct Oldthhr(pub u32);Expand description
This register is used for the adjustment of the Out-off Limit high threshold.
Tuple Fields
0: u32Implementations
impl Oldthhr
impl Oldthhr
pub const fn oldthh(&self) -> u32
pub const fn oldthh(&self) -> u32
OLD High Threshold Value Set and cleared by software. OLDTHH represents a 26-bit signed value. The real threshold compared to the signal provided by the filter is OLDTHH. This field can be write-protected, please refer to Section 1.4.15: Register protection for details.
pub const fn set_oldthh(&mut self, val: u32)
pub const fn set_oldthh(&mut self, val: u32)
OLD High Threshold Value Set and cleared by software. OLDTHH represents a 26-bit signed value. The real threshold compared to the signal provided by the filter is OLDTHH. This field can be write-protected, please refer to Section 1.4.15: Register protection for details.