Struct Snpsdr
#[repr(transparent)]pub struct Snpsdr(pub u32);Expand description
This register is used to read the data processed by each digital filter in snapshot mode.
Tuple Fields
0: u32Implementations
impl Snpsdr
impl Snpsdr
pub const fn mcicdc(&self) -> u16
pub const fn mcicdc(&self) -> u16
Contains the MCIC decimation counter value at the moment of the last trigger event occurs (MCIC_CNT).
pub const fn set_mcicdc(&mut self, val: u16)
pub const fn set_mcicdc(&mut self, val: u16)
Contains the MCIC decimation counter value at the moment of the last trigger event occurs (MCIC_CNT).
pub const fn extsdr(&self) -> u8
pub const fn extsdr(&self) -> u8
Extended data size If SNPSFMT = 0 , EXTSDR[6:0] contains the bit 7 to 1 of the last valid data processed by the digital filter, If SNPSFMT = 1 , this field contains the INT accumulator counter value at the moment of the last trigger event occurs (INT_CNT).
pub const fn set_extsdr(&mut self, val: u8)
pub const fn set_extsdr(&mut self, val: u8)
Extended data size If SNPSFMT = 0 , EXTSDR[6:0] contains the bit 7 to 1 of the last valid data processed by the digital filter, If SNPSFMT = 1 , this field contains the INT accumulator counter value at the moment of the last trigger event occurs (INT_CNT).